Reactivated PI get emails
[myslice.git] / setup.py
index 2eeb598..d7008a3 100644 (file)
--- a/setup.py
+++ b/setup.py
@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
# Setup script for myslice
 #
 # Thierry Parmentelat <thierry.parmentelat@inria.fr>
 # INRIA (c) 2013
@@ -9,14 +9,19 @@ import os.path
 from glob import glob
 from distutils.core import setup
 
-# we don't have a final list os let's keep it simple for now
+# we don't have a final list so let's keep it simple for now
 packages= [ os.path.dirname(init) for init in (glob("*/__init__.py")+glob("*/*/__init__.py")) ]
 
 setup(packages = packages,
-      scripts = [],
+      # xxx somehow this does not seem to show up in debian packaging
+      scripts = [ 'apache/unfold-init-ssl.sh' ],
       data_files = [ 
-        ( 'all-static/js', glob ('all-static/js/*')),
-        ( 'all-static/css', glob ('all-static/css/*')),
-        ( 'all-static/img', glob ('all-static/img/*')),
-        ( 'all-templates', glob ('all-templates/*')),
+          ( '/usr/share/unfold/static/js', glob ('static/js/*')),
+          ( '/usr/share/unfold/static/css', glob ('static/css/*')),
+          ( '/usr/share/unfold/static/img', glob ('static/img/*')),
+          ( '/usr/share/unfold/static/fonts', glob ('static/fonts/*')),
+          ( '/usr/share/unfold/templates', glob ('templates/*')),
+          ( 'apache', [ 'apache/unfold.conf', 'apache/unfold-ssl.conf', 'apache/unfold.wsgi' ]),
+          ( '/etc/unfold/trusted_roots', []),
+          ( '/var/unfold', []),
         ])
@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Setup script for myslice
+# Setup script for myslice+unfold
 #
 # Thierry Parmentelat <thierry.parmentelat@inria.fr>